# Spin-finder
Are you working with aromatic polycyclic hydrocarbons and concerned about their ground state spin? This repository demonstrates how to calculate the [spin multiplicity](https://en.wikipedia.org/wiki/Multiplicity_(chemistry)) (2S+1) of large PAH using our own algorithm based on [Ovchinnikov's rule](https://link.springer.com/article/10.1007/bf00549259).

Spin finder requires the installation of the following libraries:

*  [`pandas`](https://pandas.pydata.org/)
*  [`rdkit`](https://www.rdkit.org/docs/Install.html)
*  [`openbabel`](https://openbabel.org/docs/dev/UseTheLibrary/PythonInstall.html)
